import os
import sys

def adaline():
    _read_file('adaline.txt')

def boosting():
    _read_file('boosting.txt')

def dimRed():
    _read_file('dimRed.txt')

def elbowKmeans():
    _read_file('elbowKmeans.txt')

def intro():
    _read_file('intro.txt')

def logReg():
    _read_file('logReg.txt')

def perceptron():
    _read_file('perceptron.txt')

def perceptronGreDes():
    _read_file('perceptronGreDes.txt')

def prolog8():
    _read_file('prolog8.txt')

def prologTic():
    _read_file('prologTic.txt')

def prologWater():
    _read_file('prologWater.txt')

def randomForest():
    _read_file('randomForest.txt')

def svm():
    _read_file('svm.txt')


def all():
    """
    Print all available model file names listed in all.txt
    """
    _read_file('all.txt')

def _read_file(filename):
    base_path = os.path.dirname(__file__)
    file_path = os.path.join(base_path, filename)
    try:
        with open(file_path, 'r', encoding='utf-8') as f:
            # Safely print even if terminal can't handle certain unicode characters
            text = f.read()
            sys.stdout.buffer.write(text.encode('utf-8'))
    except FileNotFoundError:
        print(f"{filename} not found.")



from setuptools import setup, find_packages

setup(
    name='gyatModel2',
    version='0.1.6',
    packages=find_packages(),
    include_package_data=True,
    package_data={
        'gyat_model': [
            'adaline.txt',
            'boosting.txt',
            'dimRed.txt',
            'elbowKmeans.txt',
            'intro.txt',
            'logReg.txt',
            'perceptron.txt',
            'perceptronGreDes.txt',
            'prolog8.txt',
            'prologTic.txt',
            'prologWater.txt',
            'randomForest.txt',
            'svm.txt',
            'model2.txt',
            'model3.txt',
            'all.txt'
        ],
    },
    author='Micheal Scofield',
    description='A sample package that prints content of AI/ML model text files',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    classifiers=[
        'Programming Language :: Python :: 3',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)
